# Docker Model Runner Provider

This module contributes to the Drupal community by integrating **[Docker Model Runner**](https://docs.docker.com/ai/model-runner/) functionality with the [Drupal AI module](https://www.drupal.org/project/ai). In its initial alpha version, this module focuses on **Chat** functionality, leveraging the `ChatInterface` provided by the Drupal AI module.

## Why This Module? Unlock Local AI Power in Drupal!

Tired of relying on external APIs and unexpected bills while experimenting with AI? This module is built for you. It lets you **seamlessly integrate cutting-edge AI models directly into your local Drupal environment**, without incurring API costs and with surprisingly straightforward setup.

We embrace the same philosophy as Docker's innovative **"Models" feature (currently in Beta)**: we want to empower you to **test, experiment, and build AI solutions** safely and efficiently. Imagine the freedom to innovate with language models without worrying about credits. **It's your personal AI sandbox for Drupal!**

## Requirements

To use this module, you need **Docker Model Runner** running on your system.

* **Docker Engine or Docker Desktop:**
* Windows: Version 4.21+
* macOS: Version 4.20+
* **Recommended for:** Docker Desktop for Mac with Apple Silicon or Windows with NVIDIA GPUs.

### Verify Docker Model Runner is Running

Open your terminal and run the following command to ensure Docker Model Runner is active:

```bash
docker model status
```

You should see output similar to this:

```plaintext
Docker Model Runner is running

Status:
llama.cpp: running llama.cpp latest-metal (sha256:hash) version: 1e8659e
```

## Get Started Experimenting in Minutes!
1. **Pull an AI Model:** Once Docker Model Runner is confirmed to be running, the next step is simple: pull one or more AI models directly to your machine. Explore endless possibilities in the [Docker Hub Generative AI Catalog](https://hub.docker.com/catalogs/models).

For example, to pull a popular model like `ai/qwen2.5:`

```bash
docker model pull ai/qwen2.5:0.5B-F16
```
2. **Install the Module:** Install the `Docker Model Runner Provider` module on your Drupal site just like any other module.

3. **Configure Your Provider and Assistant:** Head over to the AI module's configuration in Drupal. Create and configure your first AI provider and assistant, selecting one of your locally available models. **You'll be generating AI interactions in Drupal with your own models in minutes!**


## Docker Model Runner API Considerations
The current Beta version of Docker Model Runner is compatible with the OpenAI API, making integration familiar for many developers. Please note that not all OpenAI API methods are currently available. However, we're committed to keeping pace with Docker: as they release new updates for Model Runner, this module will be updated to offer the latest support.

## Support and Documentation
For any questions regarding Docker Model Runner setup or usage, we strongly recommend consulting the [official Docker AI documentation](https://docs.docker.com/ai/model-runner/).


> **Go ahead and give it a try, and take your AI developments in Drupal to the next level with the control and flexibility that only local
> execution can offer! Your feedback is invaluable to help this
> integration grow.**
