<?php

namespace Drupal\ai_provider_docker\Client;

use Drupal\Core\Config\ImmutableConfig;
use Psr\Http\Client\ClientInterface;

/**
 * Factory class for creating AI clients based on the API mode.
 */
class AiClientFactory {

  /**
   * Creates an AI client based on the specified API mode.
   *
   * @param \Psr\Http\Client\ClientInterface $http_client
   *   The HTTP client.
   * @param \Drupal\Core\Config\ImmutableConfig $config
   *   The configuration containing the API settings.
   *
   * @return \Drupal\ai_provider_docker\Client\AiClientInterface
   *   An instance of the AI client.
   */
  public static function createClient(ClientInterface $http_client, ImmutableConfig $config): AiClientInterface {
    switch ($config->get('api_mode')) {
      case 'openai':
      default:
        $client = \OpenAI::factory()
          ->withHttpClient($http_client)
          ->withBaseUri($config->get('host'))
          ->make();
        return new OpenAiClient($client);
    }
  }

}
