<?php

namespace Drupal\ai_provider_docker\Client;

use Drupal\ai\OperationType\Chat\ChatInput;
use Drupal\ai\OperationType\Embeddings\EmbeddingsInput;

/**
 * Interface for the AI client.
 */
interface AiClientInterface {

  /**
   * Get models from docker model runner.
   *
   * @return array
   *   An associative array of model IDs.
   */
  public function getModels(): array;

  /**
   * Builds the payload for a chat request.
   *
   * @param mixed $input
   *   The input data.
   * @param string $model_id
   *   The model ID.
   * @param array $tags
   *   Tags for the request.
   * @param string $chat_system_role
   *   The system role for the chat.
   * @param array $configuration
   *   Additional configuration.
   *
   * @return array
   *   The constructed payload.
   */
  public function buildChatPayload(array|string|ChatInput $input, string $model_id, array $tags, mixed $chat_system_role, array $configuration): array;

  /**
   * Executes the chat request.
   *
   * @param array $payload
   *   The payload for the request.
   *
   * @return array
   *   The response from the AI provider.
   */
  public function executeChatRequest(array $payload): array;

  /**
   * Builds the payload for an embeddings request.
   *
   * @param string|EmbeddingsInput $input
   *   The input data for embeddings.
   * @param string $model_id
   *   The model ID to use.
   * @param array $tags
   *   Tags for the request.
   * @param array $configuration
   *   Additional configuration.
   *
   * @return array
   *   The constructed payload for embeddings.
   */
  public function buildEmbeddingsPayload(string|EmbeddingsInput $input, string $model_id, array $tags, array $configuration): array;

  /**
   * Executes the embeddings request.
   *
   * @param array $payload
   *   The payload for the embeddings request.
   *
   * @return array
   *   The response from the AI provider containing embeddings.
   */
  public function executeEmbeddingsRequest(array $payload): array;

}
