<?php

declare(strict_types=1);

namespace Drupal\ai_provider_docker\Form;

use Drupal\ai\AiProviderPluginManager;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Docker Model Runner AI Provider settings.
 */
final class DockerModelRunnerConfigForm extends ConfigFormBase {

  /**
   * Config settings.
   */
  const CONFIG_NAME = 'ai_provider_docker.settings';

  /**
   * The AI provider manager.
   *
   * @var \Drupal\ai\AiProviderPluginManager
   */
  protected $aiProviderManager;

  /**
   * Module Handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a new AnthropicConfigForm object.
   */
  final public function __construct(AiProviderPluginManager $ai_provider_manager, ModuleHandlerInterface $module_handler) {
    $this->aiProviderManager = $ai_provider_manager;
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  final public static function create(ContainerInterface $container) {
    return new static(
      $container->get('ai.provider'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'docker_model_runner_provider_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['ai_provider_docker.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config(static::CONFIG_NAME);

    $form['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Host'),
      '#description' => $this->t('Need help identifying your host? <a href=":link" target="_blank">See the official documentation</a>. The host value may vary depending on whether you are using Docker Desktop or Docker Engine, and whether you are accessing it from within a container or from another environment.', [
        ':link' => 'https://docs.docker.com/ai/model-runner/#what-api-endpoints-are-available',
      ]),
      '#default_value' => $config->get('host') ?? '',
    ];

    $form['api_mode'] = [
      '#type' => 'select',
      '#title' => $this->t('API Compatibility Mode'),
      '#options' => [
        'openai' => $this->t('OpenAI API Compatible'),
      ],
      '#default_value' => $config->get('api_mode') ?? 'openai',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->aiProviderManager->defaultIfNone('chat', 'docker_model_runner', '');

    $this->config('ai_provider_docker.settings')
      ->set('api_mode', $form_state->getValue('api_mode'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
